@@ -87,7 +87,7 @@ async def _get_text_data(text: str) -> dict:
     return data
 
 
-async def upload_image(image: Picture, credential: Credential) -> Picture:
+async def upload_image(image: Picture, credential: Credential) -> dict:
     """
     上传动态图片
 
@@ -96,7 +96,7 @@ async def upload_image(image: Picture, credential: Credential) -> Picture:
         credential   (Credential): 凭据
 
     Returns:
-        Picture: 图片类
+        dict: 调用 API 返回的结果
     """
     credential.raise_for_no_sessdata()
     credential.raise_for_no_bili_jct()
@@ -106,14 +106,11 @@ async def upload_image(image: Picture, credential: Credential) -> Picture:
 
     data = {"biz": "new_dyn", "category": "daily"}
 
-
     return_info = await request(
         "POST",
         url=api["url"],
         data=data,
-        files={
-            "file_up": raw
-        },
+        files={"file_up": raw},
         credential=credential,
     )
 
@@ -135,16 +132,7 @@ async def _get_draw_data(
         *[upload_image(stream, credential) for stream in images]
     )
 
-    def transformPicInfo(image: Picture):
-        """
-        转换图片信息
-
-        Args:
-            image (Picture): 图片类
-
-        Returns:
-            dict: 图片信息
-        """
+    def transformPicInfo(image: dict):
         return {
             "img_src": image["image_url"],
             "img_width": image["image_width"],
@@ -207,14 +195,14 @@ async def send_dynamic(
 
     async def instant_draw():
         api = API["send"]["instant_draw"]
-        data = await _get_draw_data(text, images, credential) # type: ignore
+        data = await _get_draw_data(text, images, credential)  # type: ignore
         return await request("POST", api["url"], data=data, credential=credential)
 
     async def schedule(type_: int):
         api = API["send"]["schedule"]
         if type_ == 2:
             # 画册动态
-            request_data = await _get_draw_data(text, images, credential) # type: ignore
+            request_data = await _get_draw_data(text, images, credential)  # type: ignore
             request_data.pop("setting")
         else:
             # 文字动态
@@ -222,7 +210,7 @@ async def send_dynamic(
 
         data = {
             "type": type_,
-            "publish_time": int(send_time.timestamp()), # type: ignore
+            "publish_time": int(send_time.timestamp()),  # type: ignore
             "request": json.dumps(request_data, ensure_ascii=False),
         }
         return await request("POST", api["url"], data=data, credential=credential)
@@ -444,7 +432,7 @@ async def get_new_dynamic_users(credential: Union[Credential, None] = None):
     credential = credential if credential else Credential()
     credential.raise_for_no_sessdata()
     api = API["info"]["attention_new_dynamic"]
-    return await request("GET", api["url"], credential = credential)
+    return await request("GET", api["url"], credential=credential)
 
 
 async def get_live_users(size: int = 10, credential: Union[Credential, None] = None):
@@ -461,10 +449,8 @@ async def get_live_users(size: int = 10, credential: Union[Credential, None] = N
     credential = credential if credential else Credential()
     credential.raise_for_no_sessdata()
     api = API["info"]["attention_live"]
-    params = {
-        "size": size
-    }
-    return await request("GET", api["url"], params = params, credential = credential)
+    params = {"size": size}
+    return await request("GET", api["url"], params=params, credential=credential)
 
 
 async def get_dynamic_page_info(credential: Credential):
@@ -478,8 +464,4 @@ async def get_dynamic_page_info(credential: Credential):
         dict: 调用 API 返回的结果
     """
     api = API["info"]["dynamic_page_info"]
-    return await request(
-        "GET",
-        api["url"],
-        credential = credential
-    )
+    return await request("GET", api["url"], credential=credential)
