@@ -13,6 +13,7 @@ from typing import Optional, List, Dict, Union
 from urllib.parse import urlparse
 import httpx
 from enum import Enum
+import datetime
 
 API = get_api("manga")
 
@@ -32,6 +33,7 @@ class MangaIndexFilter:
         - SOUTHKOREA: 韩国
         - OTHER: 其他
         """
+
         ALL = -1
         CHINA = 1
         JAPAN = 2
@@ -46,6 +48,7 @@ class MangaIndexFilter:
         - UPDATE: 更新时间
         - RELEASE_DATE: 上架时间
         """
+
         HOT = 0
         UPDATE = 1
         RELEASE_DATE = 3
@@ -58,6 +61,7 @@ class MangaIndexFilter:
         - FINISHED: 完结
         - UNFINISHED: 连载
         """
+
         ALL = -1
         FINISHED = 1
         UNFINISHED = 0
@@ -71,6 +75,7 @@ class MangaIndexFilter:
         - PAID: 付费
         - WILL_BE_FREE: 等就免费
         """
+
         ALL = -1
         FREE = 1
         PAID = 2
@@ -98,6 +103,7 @@ class MangaIndexFilter:
         - POSITIVE: 正能量
         - SCIENCE_FICTION: 科幻
         """
+
         ALL = -1
         WARM = 999
         ANCIENT = 997
@@ -147,13 +153,17 @@ class Manga:
             dict: 调用 API 返回的结果
         """
         api = API["info"]["detail"]
-        params = {
-            "comic_id": self.__manga_id
-        }
+        params = {"comic_id": self.__manga_id}
         return await request(
-            "POST", api["url"], params=params, credential=self.credential,
-            no_csrf=(False if (self.credential.has_sessdata()
-                     and self.credential.has_bili_jct()) else True)
+            "POST",
+            api["url"],
+            params=params,
+            credential=self.credential,
+            no_csrf=(
+                False
+                if (self.credential.has_sessdata() and self.credential.has_bili_jct())
+                else True
+            ),
         )
 
     async def __get_info_cached(self) -> dict:
@@ -164,7 +174,11 @@ class Manga:
             self.__info = await self.get_info()
         return self.__info
 
-    async def get_episode_info(self, episode_count: Optional[Union[int, float]] = None, episode_id: Optional[int] = None) -> dict:
+    async def get_episode_info(
+        self,
+        episode_count: Optional[Union[int, float]] = None,
+        episode_id: Optional[int] = None,
+    ) -> dict:
         """
         获取某一话的详细信息
 
@@ -189,7 +203,9 @@ class Manga:
                 raise ArgsException("episode_count 和 episode_id 中必须提供一个参数。")
         raise ArgsException("未找到对应的话")
 
-    async def get_episode_id(self, episode_count: Optional[Union[int, float]] = None) -> int:
+    async def get_episode_id(
+        self, episode_count: Optional[Union[int, float]] = None
+    ) -> int:
         """
         获取某一话的 id
 
@@ -201,7 +217,11 @@ class Manga:
         """
         return (await self.get_episode_info(episode_count=episode_count))["id"]
 
-    async def get_images_url(self, episode_count: Optional[Union[int, float]] = None, episode_id: Optional[int] = None) -> dict:
+    async def get_images_url(
+        self,
+        episode_count: Optional[Union[int, float]] = None,
+        episode_id: Optional[int] = None,
+    ) -> dict:
         """
         获取某一话的图片链接。(未经过处理，所有的链接无法直接访问)
 
@@ -221,17 +241,24 @@ class Manga:
                 raise ArgsException("episode_count 和 episode_id 中必须提供一个参数。")
             episode_id = await self.get_episode_id(episode_count)
         api = API["info"]["episode_images"]
-        params = {
-            "ep_id": episode_id
-        }
+        params = {"ep_id": episode_id}
         return await request(
-            "POST", api["url"], params=params,
-            no_csrf=(False if (self.credential.has_sessdata()
-                     and self.credential.has_bili_jct()) else True),
-            credential=self.credential
+            "POST",
+            api["url"],
+            params=params,
+            no_csrf=(
+                False
+                if (self.credential.has_sessdata() and self.credential.has_bili_jct())
+                else True
+            ),
+            credential=self.credential,
         )
 
-    async def get_images(self, episode_count: Optional[Union[int, float]] = None, episode_id: Optional[int] = None) -> List[Dict]:
+    async def get_images(
+        self,
+        episode_count: Optional[Union[int, float]] = None,
+        episode_id: Optional[int] = None,
+    ) -> List[Dict]:
         """
         获取某一话的所有图片
 
@@ -244,32 +271,47 @@ class Manga:
         Returns:
             List[Picture]: 所有的图片
         """
-        data = await self.get_images_url(episode_count=episode_count, episode_id=episode_id)
+        data = await self.get_images_url(
+            episode_count=episode_count, episode_id=episode_id
+        )
         pictures: List[Dict] = []
 
         async def get_real_image_url(url: str) -> str:
             token_api = API["info"]["image_token"]
-            datas = {
-                "urls": f"[\"{url}\"]"
-            }
+            datas = {"urls": f'["{url}"]'}
             token_data = await request(
-                "POST", token_api["url"], data=datas,
-                no_csrf=(False if (self.credential.has_sessdata()
-                         and self.credential.has_bili_jct()) else True),
-                credential=self.credential
+                "POST",
+                token_api["url"],
+                data=datas,
+                no_csrf=(
+                    False
+                    if (
+                        self.credential.has_sessdata()
+                        and self.credential.has_bili_jct()
+                    )
+                    else True
+                ),
+                credential=self.credential,
             )
             return token_data[0]["url"] + "?token=" + token_data[0]["token"]
+
         for img in data["images"]:
             url = await get_real_image_url(img["path"])
-            pictures.append({
-                "x": img["x"],
-                "y": img["y"],
-                "picture": Picture.from_content(httpx.get(url, headers=HEADERS).content, "jpg")
-            })
+            pictures.append(
+                {
+                    "x": img["x"],
+                    "y": img["y"],
+                    "picture": Picture.from_content(
+                        httpx.get(url, headers=HEADERS).content, "jpg"
+                    ),
+                }
+            )
         return pictures
 
 
-async def manga_image_url_turn_to_Picture(url: str, credential: Optional[Credential] = None) -> Picture:
+async def manga_image_url_turn_to_Picture(
+    url: str, credential: Optional[Credential] = None
+) -> Picture:
     """
     将 Manga.get_images_url 函数获得的图片 url 转换为 Picture 类。
 
@@ -285,20 +327,26 @@ async def manga_image_url_turn_to_Picture(url: str, credential: Optional[Credent
 
     async def get_real_image_url(url: str) -> str:
         token_api = API["info"]["image_token"]
-        datas = {
-            "urls": f"[\"{url}\"]"
-        }
+        datas = {"urls": f'["{url}"]'}
         token_data = await request(
-            "POST", token_api["url"], data=datas,
-            no_csrf=(False if (credential.has_sessdata()
-                     and credential.has_bili_jct()) else True)
+            "POST",
+            token_api["url"],
+            data=datas,
+            no_csrf=(
+                False
+                if (credential.has_sessdata() and credential.has_bili_jct())
+                else True
+            ),
         )
         return f'{token_data[0]["url"]}?token={token_data[0]["token"]}'
+
     url = await get_real_image_url(url)
     return Picture.from_url(url)
 
 
-async def set_follow_manga(manga: Manga, status: bool = True, credential: Optional[Credential] = None) -> dict:
+async def set_follow_manga(
+    manga: Manga, status: bool = True, credential: Optional[Credential] = None
+) -> dict:
     """
     设置追漫
 
@@ -318,20 +366,19 @@ async def set_follow_manga(manga: Manga, status: bool = True, credential: Option
         api = API["operate"]["add_favorite"]
     else:
         api = API["operate"]["del_favorite"]
-    data = {
-        "comic_ids": str(manga.get_manga_id())
-    }
+    data = {"comic_ids": str(manga.get_manga_id())}
     return await request("POST", api["url"], data=data, credential=credential)
 
 
-async def get_raw_manga_index(area: MangaIndexFilter.Area = MangaIndexFilter.Area.ALL,
-                        order: MangaIndexFilter.Order = MangaIndexFilter.Order.HOT,
-                        status: MangaIndexFilter.Status = MangaIndexFilter.Status.ALL,
-                        payment: MangaIndexFilter.Payment = MangaIndexFilter.Payment.ALL,
-                        style: MangaIndexFilter.Style = MangaIndexFilter.Style.ALL,
-                        pn: int = 1,
-                        ps: int = 18,
-                        ) -> list:
+async def get_raw_manga_index(
+    area: MangaIndexFilter.Area = MangaIndexFilter.Area.ALL,
+    order: MangaIndexFilter.Order = MangaIndexFilter.Order.HOT,
+    status: MangaIndexFilter.Status = MangaIndexFilter.Status.ALL,
+    payment: MangaIndexFilter.Payment = MangaIndexFilter.Payment.ALL,
+    style: MangaIndexFilter.Style = MangaIndexFilter.Style.ALL,
+    pn: int = 1,
+    ps: int = 18,
+) -> list:
     """
     获取漫画索引
 
@@ -356,19 +403,20 @@ async def get_raw_manga_index(area: MangaIndexFilter.Area = MangaIndexFilter.Are
         "is_free": payment.value,
         "style_id": style.value,
         "page_num": pn,
-        "page_size": ps
+        "page_size": ps,
     }
     return await request("POST", api["url"], data=data, params=params, no_csrf=True)
 
 
-async def get_manga_index(area: MangaIndexFilter.Area = MangaIndexFilter.Area.ALL,
-                    order: MangaIndexFilter.Order = MangaIndexFilter.Order.HOT,
-                    status: MangaIndexFilter.Status = MangaIndexFilter.Status.ALL,
-                    payment: MangaIndexFilter.Payment = MangaIndexFilter.Payment.ALL,
-                    style: MangaIndexFilter.Style = MangaIndexFilter.Style.ALL,
-                    pn: int = 1,
-                    ps: int = 18,
-                    ) -> List[Manga]:
+async def get_manga_index(
+    area: MangaIndexFilter.Area = MangaIndexFilter.Area.ALL,
+    order: MangaIndexFilter.Order = MangaIndexFilter.Order.HOT,
+    status: MangaIndexFilter.Status = MangaIndexFilter.Status.ALL,
+    payment: MangaIndexFilter.Payment = MangaIndexFilter.Payment.ALL,
+    style: MangaIndexFilter.Style = MangaIndexFilter.Style.ALL,
+    pn: int = 1,
+    ps: int = 18,
+) -> List[Manga]:
     """
     获取漫画索引
 
@@ -386,3 +434,40 @@ async def get_manga_index(area: MangaIndexFilter.Area = MangaIndexFilter.Area.AL
     """
     data = await get_raw_manga_index(area, order, status, payment, style, pn, ps)
     return [Manga(manga_data["season_id"]) for manga_data in data]
+
+
+async def get_manga_update(date: Union[str, datetime.datetime] = datetime.datetime.now(), pn: int = 1, ps: int = 8) -> List[Manga]:
+    """
+    获取更新推荐的漫画
+
+    Args:
+        date (Union[str, datetime.datetime]): 日期，默认为今日。
+        pn   (int)                          : 页码。Defaults to 1.
+        ps   (int)                          : 每页数量。Defaults to 8.
+    Returns:
+        List[Manga]: 漫画列表
+    """
+    api = API["info"]["update"]
+    params = {"device": "pc", "platform": "web"}
+    if isinstance(date, datetime.datetime):
+        date = date.strftime("%Y-%m-%d")
+    data = {"date": date, "page_num": pn, "page_size": ps}
+    manga_data = await request("POST", api["url"], no_csrf=True, params=params, data=data)
+    return [Manga(manga["comic_id"]) for manga in manga_data["list"]]
+
+async def get_manga_home_recommend(pn: int = 1, seed: Optional[str] = "0") -> List[Manga]:
+    """
+    获取首页推荐的漫画
+
+    Args:
+        pn   (int)                          : 页码。Defaults to 1.
+        seed (Optional[str])                : Unknown param，无需传入.
+        
+    Returns:
+        List[Manga]: 漫画列表
+    """
+    api = API["info"]["home_recommend"]
+    params = {"device": "pc", "platform": "web"}
+    data = {"page_num": pn, "seed": seed}
+    manga_data = await request("POST", api["url"], no_csrf=True, params=params, data=data)
+    return [Manga(manga["comic_id"]) for manga in manga_data["list"]]
\ No newline at end of file
