@@ -22,10 +22,12 @@ import yaml
 API = get_api("note")
 API_ARTICLE = get_api("article")
 
+
 class NoteType(Enum):
     PUBLIC = "public"
     PRIVATE = "private"
 
+
 class Note:
     """
     笔记相关
@@ -37,7 +39,7 @@ class Note:
         aid: Union[int, None] = None,
         note_id: Union[int, None] = None,
         note_type: NoteType = NoteType.PUBLIC,
-        credential: Union[Credential, None] = None
+        credential: Union[Credential, None] = None,
     ):
         """
         Args:
@@ -161,7 +163,7 @@ class Note:
         content = (await self.__get_info_cached())["content"]
         for line in content:
             if type(line["insert"]) == dict:
-                if 'imageUpload' in line["insert"]:
+                if "imageUpload" in line["insert"]:
                     img_info = line["insert"]["imageUpload"]
                     result.append(img_info)
         return result
@@ -180,7 +182,6 @@ class Note:
             result.append(Picture().from_url(url=f'https:{image["url"]}'))
         return result
 
-
     async def get_all(self) -> dict:
         """
         (仅供公开笔记)
@@ -196,7 +197,7 @@ class Note:
         resp = await sess.get(f"https://www.bilibili.com/read/cv{self.__cvid}")
         html = resp.text
 
-        match = re.search("window\.__INITIAL_STATE__=(\{.+?\});", html, re.I) # type: ignore
+        match = re.search("window\.__INITIAL_STATE__=(\{.+?\});", html, re.I)  # type: ignore
 
         if not match:
             raise ApiException("找不到信息")
@@ -242,7 +243,9 @@ class Note:
         self.credential.raise_for_no_sessdata()
 
         api = (
-            API_ARTICLE["operate"]["add_favorite"] if status else API_ARTICLE["operate"]["del_favorite"]
+            API_ARTICLE["operate"]["add_favorite"]
+            if status
+            else API_ARTICLE["operate"]["del_favorite"]
         )
 
         data = {"id": self.__cvid}
@@ -271,13 +274,17 @@ class Note:
         获取并解析笔记内容
         该返回不会返回任何值，调用该方法后请再调用 `self.markdown()` 或 `self.json()` 来获取你需要的值。
         """
+
         def parse_note(data: List[dict]):
             for field in data:
                 if not isinstance(field["insert"], str):
                     if "tag" in field["insert"].keys():
                         node = VideoCardNode()
                         node.aid = json.loads(
-                            httpx.get("https://hd.biliplus.com/api/cidinfo?cid=" + str(field["insert"]["tag"]["cid"])).text
+                            httpx.get(
+                                "https://hd.biliplus.com/api/cidinfo?cid="
+                                + str(field["insert"]["tag"]["cid"])
+                            ).text
                         )["data"]["cid"]
                         self.__children.append(node)
                     elif "imageUpload" in field["insert"].keys():
@@ -321,6 +328,7 @@ class Note:
                     else:
                         pass
                     self.__children.append(node)
+
         info = await self.get_info()
         content = info["content"]
         content = unescape(content)
@@ -329,7 +337,6 @@ class Note:
         self.__meta = await self.__get_info_cached()
         del self.__meta["content"]
 
-
     def markdown(self) -> str:
         """
         转换为 Markdown
@@ -382,11 +389,11 @@ class Node:
         pass
 
     @overload
-    def markdown(self) -> str: # type: ignore
+    def markdown(self) -> str:  # type: ignore
         pass
 
     @overload
-    def json(self) -> dict: # type: ignore
+    def json(self) -> dict:  # type: ignore
         pass
 
 
